@@ -1,3 +1,4 @@
+"""A module for mapping compounds from different nomenclatures."""
 # The MIT License (MIT)
 #
 # Copyright (c) 2018 Institute for Molecular Systems Biology, ETH Zurich.
@@ -177,7 +178,7 @@ def map_cobra_metabolites(
 
     Returns
     -------
-    dict
+    dict of str to Compound
         A map from COBRA metabolite identifiers to compounds in the cache.
 
     """
