@@ -34,7 +34,7 @@ import numpy as np
 import pandas as pd
 
 from . import PROTON_INCHI, WATER_INCHI
-from .exceptions import ParseException
+from .exceptions import MissingDissociationConstantsException, ParseException
 from .models import Compound
 from .thermodynamic_constants import Q_, default_pMg, ureg
 
@@ -605,12 +605,18 @@ class Reaction:
         """
         ddg = Q_(0.0, "kJ/mol")
         for compound, coeff in self.items(protons=False):  # ignore protons
-            ddg += coeff * compound.transform(
-                p_h=p_h,
-                ionic_strength=ionic_strength,
-                temperature=temperature,
-                p_mg=p_mg,
-            )
+            try:
+                ddg += coeff * compound.transform(
+                    p_h=p_h,
+                    ionic_strength=ionic_strength,
+                    temperature=temperature,
+                    p_mg=p_mg,
+                )
+            except MissingDissociationConstantsException as e:
+                warnings.warn(
+                    f"Cannot calculate Legendre transform for {compound}: "
+                    + str(e)
+                )
         return ddg
 
     def _sum_coefficients(self) -> float:
